# Extensions


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**topic_type** | **[str]** |  | [readonly] 
**topic_status** | **[str]** |  | [readonly] 
**topic_label** | **[str]** |  | [readonly] 
**priority** | **[str]** |  | [readonly] 
**stage** | **[str]** |  | [readonly] 
**user_id_type** | **[str]** |  | [readonly] 
**priority_colors** | **[str, none_type]** | Non standard field. Arrays of priorities and this array are in the same order. | 
**topic_status_colors** | **[str, none_type]** | Non standard field. Arrays of statuses and this array are in the same order. | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


